@@ -1,6 +1,6 @@
-/* $Id: libxfce4util-config.h.in 21068 2006-04-18 21:35:22Z benny $ */
+/* $Id: libxfce4util-config.h.in 24694 2007-01-22 14:12:39Z benny $ */
 /*-
- * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
+ * Copyright (c) 2003-2007 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -32,7 +32,7 @@ G_BEGIN_DECLS;
 
 #define LIBXFCE4UTIL_MAJOR_VERSION	4
 #define LIBXFCE4UTIL_MINOR_VERSION	4
-#define LIBXFCE4UTIL_MICRO_VERSION	0
+#define LIBXFCE4UTIL_MICRO_VERSION	2
 
 #define LIBXFCE4UTIL_CHECK_VERSION(major,minor,micro) \
   (LIBXFCE4UTIL_MAJOR_VERSION > (major) \
@@ -46,6 +46,15 @@ extern const guint libxfce4util_major_version;
 extern const guint libxfce4util_minor_version;
 extern const guint libxfce4util_micro_version;
 
+/* verify that G_GNUC_WARN_UNUSED_RESULT is defined */
+#if !defined(G_GNUC_WARN_UNUSED_RESULT)
+#if __GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4)
+#define G_GNUC_WARN_UNUSED_RESULT __attribute__((warn_unused_result))
+#else
+#define G_GNUC_WARN_UNUSED_RESULT
+#endif /* __GNUC__ */
+#endif /* !defined(G_GNUC_WARN_UNUSED_RESULT) */
+
 G_END_DECLS;
 
 #endif	/* !__LIBXFCE4UTIL_CONFIG_H__ */
